# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class CertificateOperationUpdateParameter(Model):
    """The certificate operation update parameters.

    All required parameters must be populated in order to send to Azure.

    :param cancellation_requested: Required. Indicates if cancellation was
     requested on the certificate operation.
    :type cancellation_requested: bool
    """

    _validation = {
        'cancellation_requested': {'required': True},
    }

    _attribute_map = {
        'cancellation_requested': {'key': 'cancellation_requested', 'type': 'bool'},
    }

    def __init__(self, *, cancellation_requested: bool, **kwargs) -> None:
        super(CertificateOperationUpdateParameter, self).__init__(**kwargs)
        self.cancellation_requested = cancellation_requested



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class USqlAssemblyFileInfo(Model):
    """A Data Lake Analytics catalog U-SQL assembly file information item.

    :param type: the assembly file type. Possible values include: 'Assembly',
     'Resource', 'Nodeploy'
    :type type: str or :class:`FileType
     <azure.mgmt.datalake.analytics.catalog.models.FileType>`
    :param original_path: the the original path to the assembly file.
    :type original_path: str
    :param content_path: the the content path to the assembly file.
    :type content_path: str
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'original_path': {'key': 'originalPath', 'type': 'str'},
        'content_path': {'key': 'contentPath', 'type': 'str'},
    }

    def __init__(self, type=None, original_path=None, content_path=None):
        self.type = type
        self.original_path = original_path
        self.content_path = content_path



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class CertificateImportParameters(Model):
    """The certificate import parameters.

    All required parameters must be populated in order to send to Azure.

    :param base64_encoded_certificate: Required. Base64 encoded representation
     of the certificate object to import. This certificate needs to contain the
     private key.
    :type base64_encoded_certificate: str
    :param password: If the private key in base64EncodedCertificate is
     encrypted, the password used for encryption.
    :type password: str
    :param certificate_policy: The management policy for the certificate.
    :type certificate_policy:
     ~azure.keyvault.v2016_10_01.models.CertificatePolicy
    :param certificate_attributes: The attributes of the certificate
     (optional).
    :type certificate_attributes:
     ~azure.keyvault.v2016_10_01.models.CertificateAttributes
    :param tags: Application specific metadata in the form of key-value pairs.
    :type tags: dict[str, str]
    """

    _validation = {
        'base64_encoded_certificate': {'required': True},
    }

    _attribute_map = {
        'base64_encoded_certificate': {'key': 'value', 'type': 'str'},
        'password': {'key': 'pwd', 'type': 'str'},
        'certificate_policy': {'key': 'policy', 'type': 'CertificatePolicy'},
        'certificate_attributes': {'key': 'attributes', 'type': 'CertificateAttributes'},
        'tags': {'key': 'tags', 'type': '{str}'},
    }

    def __init__(self, *, base64_encoded_certificate: str, password: str=None, certificate_policy=None, certificate_attributes=None, tags=None, **kwargs) -> None:
        super(CertificateImportParameters, self).__init__(**kwargs)
        self.base64_encoded_certificate = base64_encoded_certificate
        self.password = password
        self.certificate_policy = certificate_policy
        self.certificate_attributes = certificate_attributes
        self.tags = tags



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.cli.core.commands.parameters import get_one_of_subscription_locations
from azure.cli.core.decorators import Completer

from azure.cli.command_modules.vm._actions import load_images_from_aliases_doc, get_vm_sizes


@Completer
def get_urn_aliases_completion_list(cmd, prefix, namespace):  # pylint: disable=unused-argument
    images = load_images_from_aliases_doc(cmd.cli_ctx)
    return [i['urnAlias'] for i in images]


@Completer
def get_vm_size_completion_list(cmd, prefix, namespace):  # pylint: disable=unused-argument
    location = namespace.location
    if not location:
        location = get_one_of_subscription_locations(cmd.cli_ctx)
    result = get_vm_sizes(cmd.cli_ctx, location)
    return [r.name for r in result]


@Completer
def get_vm_run_command_completion_list(cmd, prefix, namespace):  # pylint: disable=unused-argument
    from ._client_factory import _compute_client_factory
    try:
        location = namespace.location
    except AttributeError:
        location = get_one_of_subscription_locations(cmd.cli_ctx)
    result = _compute_client_factory(cmd.cli_ctx).virtual_machine_run_commands.list(location)
    return [r.id for r in result]
